Browbeat
========

Browbeat is a performance tuning and analysis tool for OpenStack.  Browbeat is
free, Open Source software.

* Analyze and tune your Cloud for optimal performance.
* Create Rally workloads for performance and scale testing.
* Automate deployment of common data analysis tools.

Documentation
=============

Browbeat documentation is available at https://browbeat.readthedocs.io/

Resources
=========

* `Blog <https://browbeatproject.org>`_
* `Twitter <https://twitter.com/browbeatproject>`_
* `Code Review <https://review.openstack.org/#/q/project:openstack/browbeat>`_
* `Git Web <https://git.openstack.org/cgit/openstack/browbeat>`_
* `IRC <http://webchat.freenode.net/?nick=browbeat_user&channels=openstack-browbeat>`_ -- **#openstack-browbeat** (irc.freenode.net)
* `Issue tracker <https://bugs.launchpad.net/openstack-browbeat>`
* `Browse code <https://github.com/openstack/browbeat>`